@@ -4,6 +4,7 @@ import os
 import re
 import sys
 import urllib.request
+from urllib.request import url2pathname as os_url2pathname
 import warnings
 
 import h5py
@@ -32,9 +33,11 @@ from ..constants.measurement import C_OBJECTS_URL
 from ..constants.measurement import C_PATH_NAME
 from ..constants.measurement import C_SERIES
 from ..constants.measurement import C_URL
+from ..constants.measurement import DB_TEMP
 from ..constants.measurement import EXPERIMENT
 from ..constants.measurement import GROUP_INDEX
 from ..constants.measurement import GROUP_NUMBER
+from ..constants.measurement import GROUP_LENGTH
 from ..constants.measurement import IMAGE
 from ..constants.measurement import IMAGE_NUMBER
 from ..constants.measurement import K_CASE_SENSITIVE
@@ -56,7 +59,6 @@ from ..utilities.hdf5_dict import HDF5Dict, NullLock
 from ..utilities.measurement import agg_ignore_feature
 from ..utilities.measurement import get_agg_measurement_name
 from ..utilities.measurement import make_temporary_file
-from ..utilities.pathname import url2pathname
 
 
 class Measurements:
@@ -364,6 +366,15 @@ class Measurements:
 
     group_index = property(get_group_index, set_group_index)
 
+    def get_group_length(self):
+        """The group length of the current image group"""
+        return self.get_current_image_measurement(GROUP_LENGTH)
+
+    def set_group_length(self, group_length):
+        self.add_image_measurement(GROUP_LENGTH, group_length)
+
+    group_length = property(get_group_length, set_group_length)
+
     def get_groupings(self, features):
         """Return groupings of image sets based on feature values
 
@@ -741,7 +752,7 @@ class Measurements:
     def get_object_names(self):
         """The list of object names (including Image) that have measurements
         """
-        return [x for x in self.hdf5_dict.top_level_names() if x != RELATIONSHIP]
+        return [x for x in self.hdf5_dict.top_level_names() if x not in (DB_TEMP, RELATIONSHIP)]
 
     object_names = property(get_object_names)
 
@@ -815,6 +826,8 @@ class Measurements:
         #
         if getattr(v, "__class__") == str:
             return v
+        elif getattr(v, "__class__") == bytes:
+                return v.decode()
         return v
 
     def get_measurement(self, object_name, feature_name, image_set_number=None):
@@ -1195,6 +1208,9 @@ class Measurements:
                     continue
                 feature_name = "%s_%s" % (object_name, feature)
                 values = self.get_measurement(object_name, feature, image_set_number)
+                if not numpy.issubdtype(values.dtype, numpy.number):
+                    # Can't generate aggregate values for non-numeric measurements
+                    values = None
                 if values is not None:
                     values = values[numpy.isfinite(values)]
                 #
@@ -1290,6 +1306,7 @@ class Measurements:
         to_save = [
             GROUP_NUMBER,
             GROUP_INDEX,
+            GROUP_LENGTH
         ]
         to_save_prefixes = [
             C_URL,
@@ -1441,7 +1458,6 @@ class Measurements:
         if not self.has_feature(EXPERIMENT, M_PATH_MAPPINGS,):
             return url
         d = json.loads(self.get_experiment_measurement(M_PATH_MAPPINGS))
-        os_url2pathname = url2pathname
         full_name = os_url2pathname(url[5:])
         full_name_c = full_name if d[K_CASE_SENSITIVE] else full_name.lower()
         if d[K_LOCAL_SEPARATOR] != os.path.sep:
@@ -1454,8 +1470,6 @@ class Measurements:
                 if full_name_c.startswith(local_directory.lower()):
                     full_name = remote_directory + full_name[len(local_directory) :]
         url = "file:" + urllib.request.pathname2url(full_name)
-        if isinstance(url, str):
-            url = url
         return url
 
     ###########################################################
@@ -1731,7 +1745,7 @@ class Measurements:
         data = json.dumps(grouping_tags)
         self.add_experiment_measurement(M_GROUPING_TAGS, data)
 
-    def get_grouping_tags(self):
+    def get_grouping_tags_or_metadata(self):
         """Get the metadata tags that were used to group the image set
 
         """
@@ -1739,3 +1753,12 @@ class Measurements:
             return self.get_metadata_tags()
 
         return json.loads(self.get_experiment_measurement(M_GROUPING_TAGS))
+
+    def get_grouping_tags_only(self):
+        """Get the metadata tags that were used to group the image set,
+        and only those, not metadata instead
+        """
+        if not self.has_feature(EXPERIMENT, M_GROUPING_TAGS,):
+            return []
+
+        return json.loads(self.get_experiment_measurement(M_GROUPING_TAGS))
