@@ -1,9 +1,11 @@
+import contextlib
 import os
 import re
 import time
 import urllib.request
 
 import javabridge
+from javabridge.jutil import JavaException
 
 from ..constants.measurement import COLTYPE_FLOAT
 from ..constants.measurement import COLTYPE_INTEGER
@@ -43,6 +45,7 @@ from ..pipeline import Pipeline
 from ..preferences import ABSOLUTE_FOLDER_NAME
 from ..preferences import URL_FOLDER_NAME
 from ..preferences import report_progress
+from ..preferences import get_headless
 from ..setting import Binary
 from ..setting import DataTypes
 from ..setting import Divider
@@ -1072,9 +1075,13 @@ not being applied, your choice on this setting may be the culprit.
                     fltr,
                 )
             elif group.extraction_method == X_IMPORTED_EXTRACTION:
-                imported_extractor = self.build_imported_metadata_extractor(
-                    group, extractor, for_metadata_only
-                )
+                try:
+                    imported_extractor = self.build_imported_metadata_extractor(
+                        group, extractor, for_metadata_only
+                    )
+                except JavaException:
+                    imported_extractor = None
+
                 if imported_extractor is not None:
                     javabridge.call(
                         extractor,
@@ -1123,48 +1130,76 @@ not being applied, your choice on this setting may be the culprit.
         def msg(url):
             return "Processing %s" % url
 
-        import wx
         from bioformats.formatreader import get_omexml_metadata
+        from typing import Optional, Any, Callable
+        from dataclasses import dataclass
 
-        with wx.ProgressDialog(
-            "Extracting metadata",
-            msg(list(urls)[0]),
-            len(urls),
-            style=wx.PD_CAN_ABORT
-            | wx.PD_APP_MODAL
-            | wx.PD_ELAPSED_TIME
-            | wx.PD_REMAINING_TIME,
-        ) as dlg:
-            errorcount = 0
-            for i, url in enumerate(urls):
-                try:
-                    if i > 0:
-                        keep_going, _ = dlg.Update(i, msg(url))
-                        if not keep_going:
+        @dataclass
+        class ui_context:
+            dlg: Optional[Any]
+            update_callback: Callable[[Any, int, str], bool]
+            err_callback: Callable[[str], None]
+
+        @contextlib.contextmanager
+        def get_pbar_context():
+            if get_headless():
+                def err_callback(msg):
+                    raise ValueError(msg)
+                yield ui_context(None, lambda *_: True, err_callback)
+            else:
+                import wx
+                with wx.ProgressDialog(
+                        "Extracting metadata",
+                        msg(list(urls)[0]),
+                        len(urls),
+                        style=wx.PD_CAN_ABORT
+                              | wx.PD_APP_MODAL
+                              | wx.PD_ELAPSED_TIME
+                              | wx.PD_REMAINING_TIME,
+                ) as dlg:
+                    def ui_callback(_dlg, i, url):
+                        if i > 0:
+                            keep_going, _ = _dlg.Update(i, msg(url))
+                            if not keep_going:
+                                return False
+                        return True
+                    def err_callback(msg):
+                        wx.MessageBox(msg)
+                    yield ui_context(dlg, ui_callback, err_callback)
+
+        def update_all_urls():
+            with get_pbar_context() as pbar_context:
+                errorcount = 0
+                for i, url in enumerate(urls):
+                    try:
+                        if not pbar_context.update_callback(pbar_context.dlg, i, url):
                             break
-                    if group.filter_choice == F_FILTERED_IMAGES:
-                        match = group.filter.evaluate(
-                            (
-                                FileCollectionDisplay.NODE_IMAGE_PLANE,
-                                url_to_modpath(url),
-                                self,
+                        if group.filter_choice == F_FILTERED_IMAGES:
+                            match = group.filter.evaluate(
+                                (
+                                    FileCollectionDisplay.NODE_IMAGE_PLANE,
+                                    url_to_modpath(url),
+                                    self,
+                                )
                             )
-                        )
-                        if not match:
-                            continue
-                    metadata = filelist.get_metadata(url)
-                    if metadata is None:
-                        metadata = get_omexml_metadata(url=url)
-                        filelist.add_metadata(url, metadata)
-                except:
-                    print("Metadata extraction failed for %s" % url)
-                    errorcount += 1
-            if errorcount > 0:
-                wx.MessageBox(
-                    "Metadata extraction completed with %i error(s).\n"
-                    "File(s) may be in an incompatible format or "
-                    "corrupted." % errorcount
-                )
+                            if not match:
+                                continue
+                        metadata = filelist.get_metadata(url)
+                        if metadata is None:
+                            metadata = get_omexml_metadata(url=url)
+                            filelist.add_metadata(url, metadata)
+                    except Exception as e:
+                        import logging
+                        logger = logging.getLogger(__name__)
+                        logger.exception(f"Metadata extraction failed for {url}", e)
+                        errorcount += 1
+                    if errorcount > 0:
+                        errmsg = f"Metadata extraction completed with {errorcount} error(s).\n"
+                        "File(s) may be in an incompatible format or corrupted."
+                        pbar_context.err_callback(errmsg)
+
+        update_all_urls()
+
         group.metadata_autoextracted.value = True
 
     def on_activated(self, workspace):
