@@ -1,6 +1,5 @@
 """test_Pipeline.py - test the CellProfiler.Pipeline module"""
 
-
 import cProfile
 import io
 import os
@@ -9,13 +8,14 @@ import sys
 import tempfile
 import traceback
 import unittest
+from pathlib import Path
+from importlib.util import find_spec
 
 import numpy
 import numpy.lib.index_tricks
 import six
 import six.moves
 
-
 import tests.modules
 from cellprofiler_core.constants.measurement import (
     COLTYPE_INTEGER,
@@ -45,6 +45,7 @@ from cellprofiler_core.pipeline import (
     MeasurementDependency,
     LoadException,
 )
+from cellprofiler_core.pipeline.io._v6 import dump, load
 from cellprofiler_core.preferences import (
     set_headless,
     set_default_output_directory,
@@ -86,13 +87,13 @@ def module_directory():
 def image_with_one_cell(size=(100, 100)):
     img = numpy.zeros(size)
     mgrid = numpy.lib.index_tricks.nd_grid()
-    g = mgrid[0 : size[0], 0 : size[1]] - 50
+    g = mgrid[0: size[0], 0: size[1]] - 50
     dist = (
-        g[0, :, :] * g[0, :, :] + g[1, :, :] * g[1, :, :]
+            g[0, :, :] * g[0, :, :] + g[1, :, :] * g[1, :, :]
     )  # squared Euclidean distance.
     img[dist < 25] = (
-        25.0 - dist.astype(float)[dist < 25]
-    ) / 25  # A circle centered at (50, 50)
+                             25.0 - dist.astype(float)[dist < 25]
+                     ) / 25  # A circle centered at (50, 50)
     return img
 
 
@@ -127,6 +128,7 @@ class TestPipeline(unittest.TestCase):
         set_headless()
         self.new_output_directory = os.path.normcase(tempfile.mkdtemp())
         set_default_output_directory(self.new_output_directory)
+        self.cpinstalled = find_spec("cellprofiler") != None
 
     def tearDown(self):
         subdir = self.new_output_directory
@@ -187,7 +189,7 @@ HasImagePlaneDetails:False"""
         module.my_variable.value = "foo"
         x.add_module(module)
         columns = x.get_measurement_columns()
-        assert len(columns) == 9
+        assert len(columns) == 10
         assert any(
             [
                 column[0] == "Image"
@@ -204,6 +206,14 @@ HasImagePlaneDetails:False"""
                 for column in columns
             ]
         )
+        assert any(
+            [
+                column[0] == "Image"
+                and column[1] == "Group_Length"
+                and column[2] == COLTYPE_INTEGER
+                for column in columns
+            ]
+        )
         assert any(
             [
                 column[0] == "Image" and column[1] == "ModuleError_01MeasurementFixture"
@@ -239,18 +249,18 @@ HasImagePlaneDetails:False"""
         assert any([column[1] == "foo" for column in columns])
         module.my_variable.value = "bar"
         columns = x.get_measurement_columns()
-        assert len(columns) == 9
+        assert len(columns) == 10
         assert any([column[1] == "bar" for column in columns])
         module = MeasurementFixture()
         module.set_module_num(2)
         module.my_variable.value = "foo"
         x.add_module(module)
         columns = x.get_measurement_columns()
-        assert len(columns) == 12
+        assert len(columns) == 13
         assert any([column[1] == "foo" for column in columns])
         assert any([column[1] == "bar" for column in columns])
         columns = x.get_measurement_columns(module)
-        assert len(columns) == 9
+        assert len(columns) == 10
         assert any([column[1] == "bar" for column in columns])
 
     def test_all_groups(self):
@@ -269,10 +279,10 @@ HasImagePlaneDetails:False"""
             for group_number_idx, (grouping, image_numbers) in enumerate(groupings):
                 for group_idx, image_number in enumerate(image_numbers):
                     workspace.measurements["Image", GROUP_NUMBER, image_number,] = (
-                        group_number_idx + 1
+                            group_number_idx + 1
                     )
                     workspace.measurements["Image", GROUP_INDEX, image_number,] = (
-                        group_idx + 1
+                            group_idx + 1
                     )
             expects[0], expects[1] = ("PrepareGroup", 0)
             return True
@@ -362,10 +372,10 @@ HasImagePlaneDetails:False"""
             for group_number_idx, (grouping, image_numbers) in enumerate(groupings):
                 for group_idx, image_number in enumerate(image_numbers):
                     workspace.measurements["Image", GROUP_NUMBER, image_number,] = (
-                        group_number_idx + 1
+                            group_number_idx + 1
                     )
                     workspace.measurements["Image", GROUP_INDEX, image_number,] = (
-                        group_idx + 1
+                            group_idx + 1
                     )
             expects[0], expects[1] = ("PrepareGroup", 1)
             return True
@@ -555,6 +565,94 @@ HasImagePlaneDetails:False"""
                 success = False
         assert success
 
+    def test_load_json(self):
+        pipeline_v5 = get_empty_pipeline()
+        pipeline_v6 = get_empty_pipeline()
+
+        if self.cpinstalled:
+            v5_pathname = os.path.realpath(
+                os.path.join(os.path.dirname(__file__), "../data/pipeline/v5_ExampleFly.cppipe")
+            )
+            v6_pathname = os.path.realpath(
+                os.path.join(os.path.dirname(__file__), "../data/pipeline/v6_ExampleFly.json")
+            )
+        else:
+            v5_pathname = os.path.realpath(
+                os.path.join(os.path.dirname(__file__), "../data/pipeline/v5_coreOnly.cppipe")
+            )
+            v6_pathname = os.path.realpath(
+                os.path.join(os.path.dirname(__file__), "../data/pipeline/v6_coreOnly.json")
+            )
+
+        pipeline_v5.load(v5_pathname)
+        with open(v6_pathname, "r") as fd:
+            load(pipeline_v6, fd)
+
+        modules_v5 = pipeline_v5.modules()
+        modules_v6 = pipeline_v6.modules()
+        for module_v5, module_v5 in zip(modules_v5, modules_v6):
+            for setting_in, setting_out in zip(module_v5.settings(), module_v5.settings()):
+                assert setting_in.value == setting_out.value
+
+    def test_dump_json(self):
+        pipeline = get_empty_pipeline()
+        module = instantiate_module("Images")
+        module.set_module_num(1)
+        pipeline.add_module(module)
+        temp_file = tempfile.NamedTemporaryFile(mode="w+b", suffix=".json", delete=False)
+        print(temp_file.name)
+        with open(temp_file.name, "w") as fp:
+            dump(pipeline, fp, save_image_plane_details=True)
+            fp.seek(0)
+        temp_file.flush()
+        fp.close()
+
+        import json
+        with open(os.path.realpath(
+            os.path.join(os.path.dirname(__file__), "../data/pipeline/images.json")
+            ), 
+            "r") as fd:
+            pipeline_groundtruth = json.load(fd)
+        with open(temp_file.name, "r") as fp:
+            pipeline_v6 = json.load(fp)
+
+        assert len(pipeline_groundtruth.keys()) == len(pipeline_v6.keys())
+        for key in pipeline_groundtruth.keys():
+            if "modules" in key:
+                for setting_v6, setting_gt in zip(pipeline_v6["modules"][0]["settings"], pipeline_groundtruth["modules"][0]["settings"]):
+                    assert setting_v6["value"] == setting_gt["value"]
+                    assert setting_v6["name"] == setting_gt["name"]
+                    assert setting_v6["text"] == setting_gt["text"]
+            else:
+                if key != "date_revision":
+                    assert pipeline_groundtruth[key] == pipeline_v6[key]
+
+    def test_load_and_dump_json(self):
+        pipeline = get_empty_pipeline()
+        pathname = os.path.realpath(
+            os.path.join(os.path.dirname(__file__), "../data/pipeline/v5_ExampleFly.cppipe")
+        )
+        pipeline.load(pathname)
+
+        temp_file = tempfile.NamedTemporaryFile(mode="w+b", suffix=".json", delete=False)
+        with open(temp_file.name, "w") as fp:
+            dump(pipeline, fp, save_image_plane_details=True)
+            fp.seek(0)
+        temp_file.flush()
+        fp.close()
+
+        new_pipeline = get_empty_pipeline()
+        with open(temp_file.name, "r") as fp:
+            fp.seek(0)
+            load(new_pipeline, fp)
+
+        modules_in = pipeline.modules()
+        modules_out = new_pipeline.modules()
+        for module_in, module_out in zip(modules_in, modules_out):
+            for setting_in, setting_out in zip(module_in.settings(), module_out.settings()):
+                assert setting_in.value == setting_out.value
+                assert setting_in.text == setting_out.text
+
     def test_dump(self):
         pipeline = get_empty_pipeline()
         fill_modules()
@@ -674,7 +772,7 @@ HasImagePlaneDetails:False"""
         assert value == "∢8"
         mline = lines[7]
         idx0 = mline.find("notes:")
-        mline = mline[(idx0 + 6) :]
+        mline = mline[(idx0 + 6):]
         idx1 = mline.find("|")
         value = eval(mline[:idx1])
         assert value == module.notes
@@ -705,7 +803,7 @@ HasImagePlaneDetails:False"""
         pipeline.loadtxt(fd)
         assert len(pipeline.modules()) == 1
         result_module = pipeline.modules()[0]
-        assert isinstance(result_module, MeasurementFixture,)
+        assert isinstance(result_module, MeasurementFixture, )
         assert module.notes == result_module.notes
         assert module.my_variable.value == result_module.my_variable.value
 
@@ -728,7 +826,7 @@ HasImagePlaneDetails:False"""
         module.notes = "αβ"
         assert len(pipeline.modules()) == 1
         result_module = pipeline.modules()[0]
-        assert isinstance(result_module, MeasurementFixture,)
+        assert isinstance(result_module, MeasurementFixture, )
         assert module.notes == result_module.notes
         assert module.my_variable.value == result_module.my_variable.value
 
@@ -791,16 +889,16 @@ HasImagePlaneDetails:False"""
 
     def test_get_provider_dictionary_nothing(self):
         for module in (
-            ATestModule(),
-            ATestModule([Choice("foo", ["Hello", "World"])]),
+                ATestModule(),
+                ATestModule([Choice("foo", ["Hello", "World"])]),
         ):
             pipeline = get_empty_pipeline()
             module.set_module_num(1)
             pipeline.add_module(module)
             for groupname in (
-                "imagegroup",
-                "objectgroup",
-                "measurementsgroup",
+                    "imagegroup",
+                    "objectgroup",
+                    "measurementsgroup",
             ):
                 d = pipeline.get_provider_dictionary(groupname)
                 assert len(d) == 0
@@ -966,10 +1064,10 @@ HasImagePlaneDetails:False"""
 
     def test_get_dependency_graph_empty(self):
         for module in (
-            ATestModule(),
-            ATestModule([Choice("foo", ["Hello", "World"])]),
-            ATestModule([ImageName("foo", IMAGE_NAME)]),
-            ATestModule([ImageName("foo", IMAGE_NAME)]),
+                ATestModule(),
+                ATestModule([Choice("foo", ["Hello", "World"])]),
+                ATestModule([ImageName("foo", IMAGE_NAME)]),
+                ATestModule([ImageName("foo", IMAGE_NAME)]),
         ):
             pipeline = Pipeline()
             module.set_module_num(1)
@@ -980,11 +1078,11 @@ HasImagePlaneDetails:False"""
     def test_get_dependency_graph_image(self):
         pipeline = Pipeline()
         for i, module in enumerate(
-            (
-                ATestModule([ImageName("foo", IMAGE_NAME)]),
-                ATestModule([ImageName("foo", ALT_IMAGE_NAME)]),
-                ATestModule([ImageName("foo", IMAGE_NAME)]),
-            )
+                (
+                        ATestModule([ImageName("foo", IMAGE_NAME)]),
+                        ATestModule([ImageName("foo", ALT_IMAGE_NAME)]),
+                        ATestModule([ImageName("foo", IMAGE_NAME)]),
+                )
         ):
             module.module_num = i + 1
             pipeline.add_module(module)
@@ -1001,11 +1099,11 @@ HasImagePlaneDetails:False"""
     def test_get_dependency_graph_object(self):
         pipeline = Pipeline()
         for i, module in enumerate(
-            (
-                ATestModule([LabelName("foo", OBJECT_NAME)]),
-                ATestModule([ImageName("foo", IMAGE_NAME)]),
-                ATestModule([LabelName("foo", OBJECT_NAME)]),
-            )
+                (
+                        ATestModule([LabelName("foo", OBJECT_NAME)]),
+                        ATestModule([ImageName("foo", IMAGE_NAME)]),
+                        ATestModule([LabelName("foo", OBJECT_NAME)]),
+                )
         ):
             module.module_num = i + 1
             pipeline.add_module(module)
@@ -1024,11 +1122,11 @@ HasImagePlaneDetails:False"""
         measurement_columns = [(OBJECT_NAME, FEATURE_NAME, COLTYPE_FLOAT,)]
         measurement_setting = Measurement("text", lambda: OBJECT_NAME, FEATURE_NAME)
         for i, module in enumerate(
-            (
-                ATestModule(measurement_columns=measurement_columns),
-                ATestModule([ImageName("foo", ALT_IMAGE_NAME)]),
-                ATestModule([measurement_setting]),
-            )
+                (
+                        ATestModule(measurement_columns=measurement_columns),
+                        ATestModule([ImageName("foo", ALT_IMAGE_NAME)]),
+                        ATestModule([measurement_setting]),
+                )
         ):
             module.module_num = i + 1
             pipeline.add_module(module)
@@ -1073,9 +1171,9 @@ HasImagePlaneDetails:False"""
         for metadata_columns, body_lines, expected in test_data:
             s = '"%s":"%d","%s":"%d"\n' % ("Version", 1, "PlaneCount", len(body_lines),)
             s += (
-                '"'
-                + '","'.join(["URL", "Series", "Index", "Channel"] + metadata_columns)
-                + '"\n'
+                    '"'
+                    + '","'.join(["URL", "Series", "Index", "Channel"] + metadata_columns)
+                    + '"\n'
             )
 
             s += "\n".join(body_lines) + "\n"
@@ -1189,11 +1287,11 @@ def profile_pipeline(pipeline_filename, output_filename=None, always_run=True):
 
     # helper function
     def run_pipeline(
-        pipeline_filename,
-        image_set_start=None,
-        image_set_end=None,
-        groups=None,
-        measurements_filename=None,
+            pipeline_filename,
+            image_set_start=None,
+            image_set_end=None,
+            groups=None,
+            measurements_filename=None,
     ):
         pipeline = Pipeline()
         measurements = None
@@ -1248,7 +1346,7 @@ class ATestModule(Module):
     def get_categories(self, pipeline, object_name):
         categories = set()
         for cobject_name, cfeature_name, ctype in self.get_measurement_columns(
-            pipeline
+                pipeline
         ):
             if cobject_name == object_name:
                 categories.add(cfeature_name.split("_")[0])
@@ -1257,7 +1355,7 @@ class ATestModule(Module):
     def get_measurements(self, pipeline, object_name, category):
         measurements = set()
         for cobject_name, cfeature_name, ctype in self.get_measurement_columns(
-            pipeline
+                pipeline
         ):
             ccategory, measurement = cfeature_name.split("_", 1)
             if cobject_name == object_name and category == category:
@@ -1300,17 +1398,17 @@ class GroupModule(Module):
     variable_revision_number = 1
 
     def setup(
-        self,
-        groupings,
-        prepare_run_callback=None,
-        prepare_group_callback=None,
-        run_callback=None,
-        post_group_callback=None,
-        post_run_callback=None,
-        get_measurement_columns_callback=None,
-        display_callback=None,
-        display_post_group_callback=None,
-        display_post_run_callback=None,
+            self,
+            groupings,
+            prepare_run_callback=None,
+            prepare_group_callback=None,
+            run_callback=None,
+            post_group_callback=None,
+            post_run_callback=None,
+            get_measurement_columns_callback=None,
+            display_callback=None,
+            display_post_group_callback=None,
+            display_post_run_callback=None,
     ):
         self.prepare_run_callback = prepare_run_callback
         self.prepare_group_callback = prepare_group_callback
